package ubontransitdriver.paded.com.ubontransitdriver.GEOFENCE;

import android.app.IntentService;
import android.content.Intent;
import android.support.annotation.Nullable;
import android.text.TextUtils;
import android.util.Log;
import android.widget.Toast;

import com.google.android.gms.location.Geofence;
import com.google.android.gms.location.GeofencingEvent;
import com.google.android.gms.maps.model.LatLng;
import com.google.firebase.auth.FirebaseAuth;
import com.google.firebase.auth.FirebaseUser;
import com.google.firebase.database.DatabaseReference;
import com.google.firebase.database.FirebaseDatabase;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;


public class GeofenceRegistrationService extends IntentService {

    private static final String TAG = "GeoIntentService";
    private FirebaseAuth auth;
    private int bus_stop_size;
    private String[] bus_stop_list;
    private HashMap<String, Integer> AREA_LANDMARKS;

    public GeofenceRegistrationService() {
        super(TAG);
    }

    @Override
    public int onStartCommand(@Nullable Intent intent, int flags, int startId) {
        bus_stop_size = intent.getIntExtra("bus_stop_size",0);
        bus_stop_list = intent.getStringArrayExtra("bus_stop_list");
        AREA_LANDMARKS = new HashMap<String, Integer>();
        Log.d(TAG, "onStartCommand: "+bus_stop_size);
        return super.onStartCommand(intent, flags, startId);
    }

    @Override
    protected void onHandleIntent(@Nullable Intent intent) {
        auth = FirebaseAuth.getInstance();
        GeofencingEvent geofencingEvent = GeofencingEvent.fromIntent(intent);
        Log.d(TAG, "onHandleIntent: "+geofencingEvent.getTriggeringLocation());
        if (geofencingEvent.hasError()) {
            Log.d(TAG, "GeofencingEvent error " + geofencingEvent.getErrorCode());
        } else {
            int transaction = geofencingEvent.getGeofenceTransition();
            List<Geofence> geofences = geofencingEvent.getTriggeringGeofences();
            // Get the transition details as a String.
            String geofenceTransitionDetails = getGeofenceTransitionDetails(transaction, geofences);

            Log.d(TAG, "onHandleIntent: "+geofenceTransitionDetails);

//            Log.d(TAG, "onHandleIntent: "+geofences.size());
//            Geofence geofence = geofences.get(0);
//            if (transaction == Geofence.GEOFENCE_TRANSITION_ENTER && geofence.getRequestId().equals(Constants.GEOFENCE_ID_UBU)) {
//                Log.d(TAG, "You are inside Stanford University");
//            } else {
//                Log.d(TAG, "You are outside Stanford University");
//            }
        }
    }

    private String getGeofenceTransitionDetails(int geofenceTransition, List<Geofence> triggeringGeofences) {

        String geofenceTransitionString = getTransitionString(geofenceTransition);

        Log.d(TAG, "getGeofenceTransitionTYPE "+geofenceTransition);

        // Get the Ids of each geofence that was triggered.
        ArrayList<String> triggeringGeofencesIdsList = new ArrayList<>();

        for (Geofence geofence : triggeringGeofences) {
            AREA_LANDMARKS.put(geofence.getRequestId(),geofenceTransition);
            triggeringGeofencesIdsList.add(geofence.getRequestId());
        }
        String triggeringGeofencesIdsString = TextUtils.join(", ",  triggeringGeofencesIdsList);

        changeBusstopStatus();

        return geofenceTransitionString + ": " + triggeringGeofencesIdsString;
    }

    private String getTransitionString(int transitionType) {
        switch (transitionType) {
            case Geofence.GEOFENCE_TRANSITION_ENTER:
                return "Entered";
            case Geofence.GEOFENCE_TRANSITION_EXIT:
                return "Exited";
            default:
                return "Unknown Transition";
        }
    }

    private void changeBusstopStatus(){
        Log.d(TAG, "changeBusstopStatus: "+AREA_LANDMARKS);
        FirebaseUser user = auth.getCurrentUser();

            for (int i=0; i<bus_stop_size; i++){
                final String path = "active_bus/" + user.getUid()+"/busstop/"+i+"/"+bus_stop_list[i];
                DatabaseReference ref = FirebaseDatabase.getInstance().getReference(path);

                if(AREA_LANDMARKS.containsKey(bus_stop_list[i])&&AREA_LANDMARKS.get(bus_stop_list[i])==1){
                    Log.d(TAG, "changeBusstopStatus: CONTAIN IN");
                    ref.child("on_busstop_status").setValue(true);
                }else if(AREA_LANDMARKS.containsKey(bus_stop_list[i])&&AREA_LANDMARKS.get(bus_stop_list[i])==2){
                    Log.d(TAG, "changeBusstopStatus: CONTAIN OUT");
                    ref.child("path_status").setValue(true);
                }else{

                }
//                Log.d(TAG, "changeBusstopStatus: "+AREA_LANDMARKS.get(bus_stop_list[i]));
//
//                if(AREA_LANDMARKS.containsKey(bus_stop_list[i])&&AREA_LANDMARKS.get(bus_stop_list[i])==1){
//                    Log.d(TAG, "changeBusstopStatus: "+bus_stop_list[i]+" TYPE"+AREA_LANDMARKS.get(bus_stop_list[i]));
//                    ref.child("status").setValue(true);
//                }else {
//                    ref.child("status").setValue(false);
//                }

        }


    }


}
